@@ -42,7 +42,9 @@ class PageNavigator:
             self.logger.error(f"❌ No navigation path found from {from_page} to {to_page}")
             return False
 
-        self.logger.info(f"🚀 Navigating: {from_page} ➡ {to_page} via path: {[page.__repr__ for page in path]}")
+        self.logger.info(
+            f"🚀 Navigating: {from_page} ➡ {to_page} via path: {[repr(page) for page in path]}"
+        )
 
         try:
             self.perform_navigation(path, timeout)
@@ -93,13 +95,8 @@ class PageNavigator:
             current_page = path[i]
             next_page = path[i + 1]
             transition_method = current_page.edges[next_page.__class__.__name__]
-            self.logger.info(
-                f"Navigating from {current_page.__repr__} to {next_page.__repr__} "
-                f"via method {transition_method.__repr__}"
-            )
             transition_method()
 
-
     def save_graph(self, path: str = "page_graph.png"):
         self.graph_manager.save_graph_image(path)
 
